@@ -21,7 +21,7 @@ from zunclient import exceptions
 
 CREATION_ATTRIBUTES = ['name', 'image', 'command', 'cpu', 'memory',
                        'environment', 'workdir', 'labels', 'image_pull_policy',
-                       'restart_policy', 'tty', 'stdin_open', 'image_driver']
+                       'restart_policy', 'interactive', 'image_driver']
 
 
 class Container(base.Resource):
@@ -41,9 +41,11 @@ class ContainerManager(base.Manager):
             return '/v1/containers'
 
     def list(self, marker=None, limit=None, sort_key=None,
-             sort_dir=None, detail=False):
+             sort_dir=None, detail=False, all_tenants=False):
         """Retrieve a list of containers.
 
+        :param all_tenants: Optional, list containers in all tenants
+
         :param marker: Optional, the UUID of a containers, eg the last
                        containers from a previous result set. Return
                        the next result set.
@@ -70,7 +72,8 @@ class ContainerManager(base.Manager):
         if limit is not None:
             limit = int(limit)
 
-        filters = utils.common_filters(marker, limit, sort_key, sort_dir)
+        filters = utils.common_filters(marker, limit, sort_key,
+                                       sort_dir, all_tenants)
 
         path = ''
         if detail:
@@ -124,7 +127,7 @@ class ContainerManager(base.Manager):
         return self._action(id, '/stop',
                             qparams={'timeout': timeout})
 
-    def reboot(self, id, timeout):
+    def restart(self, id, timeout):
         return self._action(id, '/reboot',
                             qparams={'timeout': timeout})
 
@@ -134,13 +137,12 @@ class ContainerManager(base.Manager):
     def unpause(self, id):
         return self._action(id, '/unpause')
 
-    def logs(self, id, stdout, stderr):
-        if stdout is False and stderr is False:
-            stdout = True
-            stderr = True
+    def logs(self, id, **kwargs):
+        if kwargs['stdout'] is False and kwargs['stderr'] is False:
+            kwargs['stdout'] = True
+            kwargs['stderr'] = True
         return self._action(id, '/logs', method='GET',
-                            qparams={'stdout': stdout,
-                                     'stderr': stderr})[1]
+                            qparams=kwargs)[1]
 
     def execute(self, id, command):
         return self._action(id, '/execute',
@@ -174,3 +176,12 @@ class ContainerManager(base.Manager):
     def top(self, id, ps_args=None):
         return self._action(id, '/top', method='GET',
                             qparams={'ps_args': ps_args})[1]
+
+    def get_archive(self, id, path):
+        return self._action(id, '/get_archive', method='GET',
+                            qparams={'path': path})[1]
+
+    def put_archive(self, id, path, data):
+        return self._action(id, '/put_archive',
+                            qparams={'path': path},
+                            body={'data': data})
